<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>AliasTab</name>
    <message>
        <location filename="../aliastab.ui" line="20"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aliastab.ui" line="65"/>
        <source>Add Alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aliastab.ui" line="76"/>
        <source>Remove Alias(es)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PromptTab</name>
    <message>
        <location filename="../prompttab_fix.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="44"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Change what gives you your prompt.&lt;/p&gt;&lt;p&gt;Default - Use what prompt you had before.&lt;/p&gt;&lt;p&gt;Fancy Prompt - Uses the MX Fancy Prompt utility&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="48"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="53"/>
        <source>Fancy Prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="69"/>
        <source>Tiny</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="74"/>
        <source>Std</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="79"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="84"/>
        <source>Gentoo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="89"/>
        <source>Dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="94"/>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="99"/>
        <source>Narrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="104"/>
        <source>Wide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="109"/>
        <source>Fancy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="114"/>
        <source>Zee</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="119"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="124"/>
        <source>Curl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="132"/>
        <source>Make The Larger Prompts Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="139"/>
        <source>Make the Larger Prompts Smaller Elsewhere</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="146"/>
        <source>Use Parentheses Instead Of Square Brackets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="153"/>
        <source>No Colors(Overrides All Other Color Options)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="160"/>
        <source>Use Bold Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="167"/>
        <source>Use Double Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="174"/>
        <source>Disable Unicode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="181"/>
        <source>Muted Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="205"/>
        <source>Time Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="234"/>
        <source>Date Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="269"/>
        <source>Right Margin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="305"/>
        <source>Extra Newlines Before Prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="334"/>
        <source>Prompt Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="363"/>
        <source>Title Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="379"/>
        <source>Remove all newlines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../aliasstream.cpp" line="38"/>
        <source>
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window_fix.ui" line="20"/>
        <source>Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="35"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="46"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="85"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Applies Changes.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="88"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="99"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Closes the application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="102"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window.cpp" line="66"/>
        <source>An easy way to configure your ~/.bashrc and bash prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../window.cpp" line="288"/>
        <location filename="../window.cpp" line="290"/>
        <location filename="../window.cpp" line="292"/>
        <source>Bash Config</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
